@@ -47,7 +47,7 @@ def path(directory):
     Provide standard input format for directory selection. 
 
     @param directory: Directory to be used as default. None value will be '~/'
-    @type string: basestring
+    @type directory: basestring
     @return: Directory selected.
     @rtype: basestring
     """
@@ -60,12 +60,12 @@ def value(length, string):
     Provide standard input format for feed id entry of a specific length.
 
     @param length: Accepted length of value.
-    @type int: basestring
+    @type length: int
     @param string: Description of selection.
     @type string: basestring
     @return: Value validity and value.
     @rtype: tuple
     """
     reply = _ENTRY(string, "#" * length)
-    return (all(reply.isdigit(), len(reply) == length), reply)
+    return (all([reply.isdigit(), len(reply) == length]), reply)
 
