@@ -106,8 +106,8 @@ class Serviceconf(object):
         """
         Check for passed attribute name in stored service and common modules.
         
-        @param service: Name of a runtime attribute.
-        @type service: basestring
+        @param name: Name of a runtime attribute.
+        @type name: basestring
         @return: value of runtime attribute.
         @rtype: indetermined
         """
