@@ -70,7 +70,7 @@ def write(filepath, workpath, data, cache=None, service=None):
         
         #{ Write data for feed page
         filename = cache.mkpath(filepath=service.TOHTM(opml['title']),
-            workstore=workpath, subpath="books")
+            workpath=workpath, subpath="books")
         fileobj_page = open(filename, "w")
         fileobj_page.write(
             item(opml, rss, service).encode("ascii", "xmlcharrefreplace")
