@@ -169,7 +169,7 @@ class Download(object):
         directory = wx.DirDialog (
             parent=self._parent,
             message="Store serial audio enclosures.",
-            defaultPath=ACCOUNT.get("xLastDir", cache.HOMEDIR),
+            defaultPath=ACCOUNT.get("xLastDir", cache.HOMEPATH),
             style=wx.PD_APP_MODAL|wx.DD_DEFAULT_STYLE)
         if directory.ShowModal() == wx.ID_OK:
             ACCOUNT['xLastDir'] = directory.GetPath()
@@ -185,19 +185,17 @@ class Download(object):
             message="Please, wait while feed enclosures are downloaded.",
             maximum=len(self._encls[1]),
             style=wx.PD_APP_MODAL|wx.PD_AUTO_HIDE|wx.PD_CAN_ABORT)
-        feedtitle = service.toRss(self._encls[0])[:-4]
+        feedtitle = service.TORSS(self._encls[0])[:-4]
         progressdlg.SetIcon(main.app_icon())
-        
         # Retrieve each epsiode placing in chosen location
         from soovee_lib.report import Hook
         hook = Hook(interface=progressdlg, service=service)
         try:
-            for eps, url in ((service.LASTTWO.match(url), url) 
-                for url in self._encls
-                ):
+            for url in self._encls[1]:
+                eps = service.LASTTWO.match(url)
                 hook.filename = "%s/%s" % (feedtitle, eps.group(2))
-                cache.Cache(pathname=url, filename=hook.filename, 
-                    hook=hook.report, workstore=ACCOUNT['xLastDir'])
+                cache.Cache(urlpath=url, filepath=hook.filename, 
+                    hook=hook.report, workpath=ACCOUNT['xLastDir'])
                 hook.count += 1
         
         except feed.UserCancel:
@@ -211,11 +209,11 @@ class Download(object):
 
         # Format an m3u playlist Forms
         from ..forms import FORMS as Forms
-        composer = Forms.get(command="m3u", formtype="enc")
+        composer = Forms.get(command="m3u", form="enc")
         for mp3file in composer.write(filepath="%s/%s.m3u" % (feedtitle,
-            feedtitle), workpath=ACCOUNT['xLastDir'], data=self._encls, 
-            cache=cache):
-            checkreturn = self._interface.Update(hook.count, 
+            feedtitle), workpath=ACCOUNT['xLastDir'], data=self._encls[1], 
+            cache=cache, service=service):
+            checkreturn = progressdlg.Update(hook.count, 
                 "Writing M3U Playlist")
             if not checkreturn[0]: 
                 raise feed.UserCancel("Download ended by user")
