@@ -36,7 +36,7 @@ Page Plugin Basic Design
 @requires: urlparse
 @requires: L{soovee_lib.plugin}
 """
-import soovee.lib.plugin as mod
+import soovee_lib.plugin as mod
 from urlparse import urljoin
 
 class _Page(mod.Loader):
@@ -55,11 +55,13 @@ class _Page(mod.Loader):
         """
         Extract the page data with the module that matches the Pages.METHOD.
 
-        @param cacheobj: Initialized soovee.lib.sv_read.
-        @type cacheobj: object
-        @param page: Nickname for page to extract data.
-        @type page: basestring
-        @param update: Default 'True'. Force sv_read to load from the network.
+        @param method: Nickname for page to extract data.
+        @type method: basestring
+        @param cache: Initialized soovee_lib.cache.
+        @type cache: object
+        @param service: Initialized soovee_app.conf.ServiceConf.
+        @type service: object
+        @param update: Default 'True'. Force cache to load from the network.
         @type update: bool
         @return: Possible filename and Opml style dict.
         @rtype: str, dict
