@@ -23,7 +23,7 @@ service acount Opml list and then update each Rss feed listed.
     - C{len(Refresh)}
     - C{[feed for feed in Refresh(cache, path)}
 
-@request: L{soovee_lib.parse}
+@requires: L{soovee_lib.parse}
 """
 from parse import Xml
 
@@ -42,12 +42,8 @@ class Refresh(object):
 
         @param cache: Initialized soovee.lib.sv_read object.
         @type cache: object
-        @param service: Initialized soovee.conf.serviceConf object.
-        @type service: object
-        @param opml: Service account opml uri
-        @type opml: basestring
-        @param store: Cache dir to store feeds.
-        @type store: basestring
+        @param path: Service account opml uri
+        @type path: basestring
         @return:
         @rtype: None
         """
